@@ -12,7 +12,8 @@ use overload    #
     my $str  = shift;
 
     return $self->class cmp $str;
-  };
+  },
+  fallback => undef;
 
 has class           => ( is => 'ro', isa => Str,  required => 1 );
 has _stop_propagate => ( is => 'rw', isa => Bool, default  => 0, init_arg => undef );
@@ -36,4 +37,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::EV::Object
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
