@@ -34,4 +34,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::H::Role
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
