@@ -1,141 +1,114 @@
 package Pcore::Src::Mercurial;
 
 use Pcore qw[-class];
-use IPC::Run qw[];
+use AnyEvent::Util qw[portable_socketpair];
 use Pcore::Src::Mercurial::File;
 
 has source => ( is => 'ro', isa => Str, required => 1 );
 
-has root => ( is => 'lazy', isa => InstanceOf ['Pcore::Util::File::Path'], init_arg => undef );
+has root => ( is => 'lazy', isa => InstanceOf ['Pcore::Util::Path'], init_arg => undef );
+has capabilities => ( is => 'ro', isa => HashRef, default => sub { {} }, init_arg => undef );
 
-has _hg => ( is => 'lazy', isa => InstanceOf ['IPC::Run'], predicate => 1, clearer => 1, init_arg => undef );
-has _in  => ( is => 'rwp', isa => FileHandle, clearer => 1, init_arg => undef );
-has _out => ( is => 'rwp', isa => FileHandle, clearer => 1, init_arg => undef );
-has _err => ( is => 'rwp', isa => FileHandle, clearer => 1, init_arg => undef );
-has _capabilities => ( is => 'rwp', isa => HashRef, default => sub { {} }, clearer => 1, init_arg => undef );
+has _in  => ( is => 'ro', init_arg => undef );    # read from child
+has _out => ( is => 'ro', init_arg => undef );    # write to child
+has _pid => ( is => 'ro', init_arg => undef );
 
 no Pcore;
 
-sub _build__hg {
-    my $self = shift;
+sub BUILD ( $self, $args ) {
+    ( my $in_r, $self->{_out} ) = portable_socketpair();
 
-    my $hg;
+    ( $self->{_in}, my $out_w ) = portable_socketpair();
 
-    my $in = \*_HG_IN;
+    $in_r->autoflush(1);
+    $self->{_in}->autoflush(1);
+    $self->{_out}->autoflush(1);
+    $out_w->autoflush(1);
 
-    my $out = \*_HG_OUT;
+    # store old STD* handles
+    open my $old_in,  '<&', \*STDIN  or die;    ## no critic qw[InputOutput::RequireBriefOpen]
+    open my $old_out, '>&', \*STDOUT or die;    ## no critic qw[InputOutput::RequireBriefOpen]
 
-    my $err = \*_HG_ERR;
+    # redirect STD* handles
+    open STDIN,  '<&', $in_r  or die;
+    open STDOUT, '>&', $out_w or die;
 
+    # spawn hg command server
     {
         my $chdir_guard = P->file->chdir( $self->source ) or die;
 
         local $ENV{HGENCODING} = 'UTF-8';
 
-        $hg = IPC::Run::start( [qw[hg --config ui.interactive=True serve --cmdserver pipe]], '<pipe', IPC::Run::binary, $in, '>pipe', IPC::Run::binary, $out, '2>pipe', $err ) or die;
-    }
+        if ($MSWIN) {
+            require Win32::Process;
 
-    $in->autoflush(1);
-    $out->autoflush(1);
-    $err->autoflush(1);
-
-    $self->_set__in($in);
-    $self->_set__out($out);
-    $self->_set__err($err);
-
-    # read capabilities
-    my ( $channel, $data ) = $self->_read_chunk;
-
-    for my $str ( split /\x0A/sm, $data ) {
-        my ( $key, $val ) = $str =~ /\A(.+)?:(.*)\z/sm;
-
-        $self->_capabilities->{$key} = $val;
-
-        if ( $key eq 'capabilities' ) {
-            $self->_capabilities->{$key} = {};
-
-            for ( grep {$_} split /\s/sm, $val ) {
-                $self->_capabilities->{$key}->{$_} = 1;
-            }
+            Win32::Process::Create(    #
+                $self->{_pid},
+                $ENV{COMSPEC},
+                '/D /C hg serve --config ui.interactive=True --cmdserver pipe',
+                1,
+                0,                     # CREATE_NEW_CONSOLE, # CREATE_NO_WINDOW,
+                q[.]
+            ) || die;
+        }
+        else {
+            exec 'hg serve --config ui.interactive=True --cmdserver pipe' or die unless fork;
         }
     }
 
-    return $hg;
+    # close child handles
+    close $in_r  or die;
+    close $out_w or die;
+
+    # restore STD* handles
+    open STDIN,  '<&', $old_in  or die;
+    open STDOUT, '>&', $old_out or die;
+
+    # read capabilities
+    my ( $ch, $data ) = $self->_read_chunk;
+
+    $self->{capabilities} = $data;
+
+    # parse real hg PID from the header
+    ( $self->{_pid} ) = $self->{capabilities} =~ /pid:\s*(\d+)/sm;
+
+    return;
 }
 
-sub _build_root {
-    my $self = shift;
+sub DEMOLISH ( $self, $global ) {
+    close $self->_in or die;
 
+    close $self->_out or die;
+
+    if ($MSWIN) {
+        Win32::Process::KillProcess( $self->_pid, 0 ) if $self->_pid;
+    }
+    else {
+        kill 9, $self->_pid or 1 if $self->_pid;
+    }
+
+    return;
+}
+
+sub _build_root ($self) {
     my $res = $self->hg_cmd('root');
 
     if ( $res->{e} ) {
         die 'No repo at this path';
     }
     else {
-        return P->file->path( $res->{o}->[0], is_dir => 1 )->realpath;
+        return P->path( $res->{o}->[0], is_dir => 1 )->realpath;
     }
 }
 
-sub disconnect {
-    my $self = shift;
-
-    if ( $self->_has_hg ) {
-        $self->_in->close if $self->_in;
-
-        $self->_out->close if $self->_out;
-
-        $self->_err->close if $self->_err;
-
-        $self->_clear_in;
-
-        $self->_clear_out;
-
-        $self->_clear_err;
-
-        IPC::Run::finish( $self->_hg );
-
-        $self->_clear_capabilities;
-    }
-
-    return;
-}
-
-sub DEMOLISH {
-    my $self = shift;
-
-    $self->disconnect;
-
-    return;
-}
-
-sub _read_chunk {
-    my $self = shift;
-
-    sysread $self->_out, my $header, 5, 0 or die;
-
-    my $channel = substr $header, 0, 1, q[];
-
-    my $len = unpack 'L>', $header;
-
-    sysread $self->_out, my $data, $len, 0 or die;
-
-    return $channel => $data;
-}
-
 # NOTE
 # status + pattern (status *.txt) not works under linux - http://bz.selenic.com/show_bug.cgi?id=4526
-sub hg_cmd {
-    my $self = shift;
-    my @cmd  = @_;
+sub hg_cmd ( $self, @cmd ) {
+    my $buf = join qq[\x00], @cmd;
 
-    # connect to server
-    $self->_hg;
+    my $cmd = qq[runcommand\x0A] . pack( 'L>', length $buf ) . $buf;
 
-    my $buff = join qq[\x00], @cmd;
-
-    my $cmd = qq[runcommand\x0A] . pack( 'L>', length $buff ) . $buff;
-
-    syswrite $self->_in, $cmd or die;
+    syswrite $self->_out, $cmd or die;
 
     my $res = {};
 
@@ -156,9 +129,7 @@ sub hg_cmd {
 }
 
 # pre-commit hook
-sub hg_pre_commit {
-    my $self = shift;
-
+sub hg_pre_commit ($self) {
     my $hg_opts = P->data->from_json( P->text->decode( $ENV{HG_OPTS_JSON}, stdin => 1 )->$*, utf8 => 0 );
 
     my $options = {};
@@ -184,20 +155,30 @@ sub hg_pre_commit {
     for my $pair ( P->list->pairs( $res->{o}->@* ) ) {
         P->text->trim( $pair->[0] );
 
-        push $commit->{files}->@*, Pcore::Src::Mercurial::File->new( { path => P->file->path( $pair->[1], base => $self->root ), status => $pair->[0] } );
+        push $commit->{files}->@*, Pcore::Src::Mercurial::File->new( { path => P->path( $pair->[1], base => $self->root ), status => $pair->[0] } );
     }
 
     return $commit;
 }
 
-sub _prepare_cmd {
-    my $self = shift;
+sub _read_chunk ($self) {
+    sysread $self->_in, my $header, 5, 0 or die;
 
+    my $channel = substr $header, 0, 1, q[];
+
+    my $len = unpack 'L>', $header;
+
+    sysread $self->_in, my $data, $len, 0 or die;
+
+    return $channel => $data;
+}
+
+sub _prepare_cmd ( $self, @args ) {
     my @cmd;
 
-    for my $arg ( grep {$_} @_ ) {
+    for my $arg ( grep {$_} @args ) {
         if ( ref $arg eq 'HASH' ) {
-            for my $key ( sort grep { $arg->{$_} } keys $arg ) {
+            for my $key ( sort grep { $arg->{$_} } keys $arg->%* ) {
                 if ( ref $arg->{$key} eq 'ARRAY' ) {
                     for my $val ( $arg->{$key}->@* ) {
                         push @cmd, qq[--$key], $val;
@@ -232,7 +213,9 @@ sub _prepare_cmd {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    2 │ 134, 136             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
+## │    3 │ 181                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    2 │ 107, 109             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -249,4 +232,10 @@ Pcore::Src::Mercurial
 
 =head1 DESCRIPTION
 
+=head1 ATTRIBUTES
+
+=head1 METHODS
+
+=head1 SEE ALSO
+
 =cut
