@@ -2,26 +2,18 @@ package Pcore::Util::File;
 
 use Pcore;
 use Fcntl qw[:DEFAULT];
-use Cwd qw[];    ## no critic qw(Modules::ProhibitEvilModules)
-use Pcore::Util::File::Path;
-
-# PATH OBJECT CONSTRUCTOR
-sub path {
-    my $self = shift;
-
-    return Pcore::Util::File::Path->NEW(@_);
-}
+use Cwd qw[];    ## no critic qw[Modules::ProhibitEvilModules]
 
 sub cat_path ( $self, @ ) {
-    return Pcore::Util::File::Path->NEW( join q[/], splice @_, 1 );
+    return P->path( join q[/], splice @_, 1 );
 }
 
 # return cwd, symlinks are resolved
 sub cwd ($self) {
-    return $self->path( Cwd::realpath(q[.]), is_dir => 1 );
+    return P->path( Cwd::realpath(q[.]), is_dir => 1 );
 }
 
-sub chdir ( $self, $path ) {    ## no critic qw(Subroutines::ProhibitBuiltinHomonyms)
+sub chdir ( $self, $path ) {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
     if ( defined wantarray ) {
         my $cwd = $self->cwd->to_string;
 
@@ -40,7 +32,7 @@ sub chdir ( $self, $path ) {    ## no critic qw(Subroutines::ProhibitBuiltinHomo
 }
 
 # change umask and return old umask
-sub umask ( $self, $mode ) {    ## no critic qw(Subroutines::ProhibitBuiltinHomonyms)
+sub umask ( $self, $mode ) {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
     return '00' if $MSWIN;
 
     if ( defined wantarray ) {
@@ -97,7 +89,7 @@ sub calc_umask ( $self, $mode, % ) {
 }
 
 # mkdir with chmod support
-sub mkdir ( $self, $path, $mode = undef ) {    ## no critic qw(Subroutines::ProhibitBuiltinHomonyms)
+sub mkdir ( $self, $path, $mode = undef ) {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
     if ( defined wantarray ) {
         if ( defined $mode ) {
             return mkdir $path, $self->calc_chmod($mode);
@@ -118,7 +110,7 @@ sub mkdir ( $self, $path, $mode = undef ) {    ## no critic qw(Subroutines::Proh
     }
 }
 
-sub chmod ( $self, $mode, @path ) {    ## no critic qw(Subroutines::ProhibitBuiltinHomonyms)
+sub chmod ( $self, $mode, @path ) {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
     if ( defined wantarray ) {
         return chmod $self->calc_chmod($mode), @path;
     }
@@ -283,7 +275,7 @@ sub read_lines ( $self, $path, % ) {
                 if ( $args{empty_lines} ) {
                     my $array_ref = [ split /\n/sm, $buf, -1 ];
 
-                    $tail = pop $array_ref;
+                    $tail = pop $array_ref->@*;
 
                     return if !$args{cb}->($array_ref);
                 }
@@ -291,10 +283,10 @@ sub read_lines ( $self, $path, % ) {
                     my $array_ref = [ split /\n+/sm, $buf ];
 
                     # remove leading q[], preserved by split
-                    shift $array_ref if defined $array_ref->[0] && $array_ref->[0] eq q[];
+                    shift $array_ref->@* if defined $array_ref->[0] && $array_ref->[0] eq q[];
 
                     if ( substr( $buf, -1, 1 ) ne qq[\n] ) {
-                        $tail = pop $array_ref;
+                        $tail = pop $array_ref->@*;
                     }
                     else {
                         $tail = q[];
@@ -329,7 +321,7 @@ sub read_lines ( $self, $path, % ) {
                 my $array_ref = [ split /\n/sm, $tail, -1 ];
 
                 # remove trailing q[], preserved by split
-                pop $array_ref if defined $array_ref->[-1] && $array_ref->[-1] eq q[];
+                pop $array_ref->@* if defined $array_ref->[-1] && $array_ref->[-1] eq q[];
 
                 return $array_ref;
             }
@@ -337,7 +329,7 @@ sub read_lines ( $self, $path, % ) {
                 my $array_ref = [ split /\n+/sm, $tail ];
 
                 # remove leading q[], preserved by split
-                shift $array_ref if defined $array_ref->[0] && $array_ref->[0] eq q[];
+                shift $array_ref->@* if defined $array_ref->[0] && $array_ref->[0] eq q[];
 
                 return $array_ref;
             }
@@ -450,7 +442,7 @@ sub _write_to_fh {
 
     for my $str (@_) {
         if ( ref $str eq 'ARRAY' ) {
-            for my $line ( $_->@* ) {
+            for my $line ( $str->@* ) {
                 print {$fh} $line, qq[\n];
             }
         }
@@ -485,7 +477,7 @@ sub read_dir ( $self, $path, % ) {
     }
 
     if ( $args{full_path} ) {
-        my $path = $self->path( $path, is_dir => 1 );
+        my $path = P->path( $path, is_dir => 1 );
 
         $files = [ map { $path . $_ } $files->@* ];
     }
@@ -531,7 +523,7 @@ sub mkpath ( $self, $path, % ) {
         @_[ 2 .. $#_ ],
     );
 
-    require File::Path;    ## no critic qw(Modules::ProhibitEvilModules)
+    require File::Path;    ## no critic qw[Modules::ProhibitEvilModules]
 
     $args{mode} = $self->calc_chmod( $args{mode} );
 
@@ -547,7 +539,7 @@ sub rmtree ( $self, $path, % ) {
         @_[ 2 .. $#_ ],
     );
 
-    require File::Path;    ## no critic qw(Modules::ProhibitEvilModules)
+    require File::Path;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return File::Path::remove_tree( "$path", \%args );
 }
@@ -559,25 +551,19 @@ sub empty_dir ( $self, $path, % ) {
         keep_root => 1,
     );
 
-    require File::Path;    ## no critic qw(Modules::ProhibitEvilModules)
+    require File::Path;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return File::Path::remove_tree( "$path", \%args );
 }
 
 # TEMP
-sub tempfile {
-    my $self = shift;
-    my %args = @_;
-
+sub tempfile ( $self, %args ) {
     require Pcore::Util::File::TempFile;
 
     return Pcore::Util::File::TempFile->new( \%args )->fh;
 }
 
-sub tempdir {
-    my $self = shift;
-    my %args = @_;
-
+sub tempdir ( $self, %args ) {
     require Pcore::Util::File::TempDir;
 
     return Pcore::Util::File::TempDir->new( \%args );
@@ -673,7 +659,7 @@ sub move ( $self, $from, $to, % ) {
 sub find {
     my $self = shift;
 
-    require File::Find;    ## no critic qw(Modules::ProhibitEvilModules)
+    require File::Find;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return File::Find::find(@_);
 }
@@ -681,7 +667,7 @@ sub find {
 sub finddepth {
     my $self = shift;
 
-    require File::Find;    ## no critic qw(Modules::ProhibitEvilModules)
+    require File::Find;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return File::Find::finddepth(@_);
 }
@@ -707,9 +693,9 @@ sub where ( $self, $filename ) {
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │                      │ Subroutines::ProhibitExcessComplexity                                                                          │
-## │      │ 56                   │ * Subroutine "calc_umask" with high complexity score (25)                                                      │
-## │      │ 130                  │ * Subroutine "calc_chmod" with high complexity score (25)                                                      │
-## │      │ 256                  │ * Subroutine "read_lines" with high complexity score (27)                                                      │
+## │      │ 48                   │ * Subroutine "calc_umask" with high complexity score (25)                                                      │
+## │      │ 122                  │ * Subroutine "calc_chmod" with high complexity score (25)                                                      │
+## │      │ 248                  │ * Subroutine "read_lines" with high complexity score (27)                                                      │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
