@@ -1,35 +1,35 @@
 package Pcore::Util::Hash::Multivalue;
 
 use Pcore;
-use List::Util qw[pairkeys];    ## no critic qw(Modules::ProhibitEvilModules)
+use List::Util qw[pairkeys];    ## no critic qw[Modules::ProhibitEvilModules]
 use Storable qw[dclone];
-
-use overload                    #
-  q[%{}] => sub {
-    return $_[0]->$*->[0];
-  },
-  fallback => undef;
+use Tie::Hash;
+use base qw[Tie::StdHash];
 
 sub new {
     my $self = shift;
 
     my $hash = {};
 
-    my $attrs = {};
+    my $obj = bless $hash, $self;
 
-    my $obj = bless \[ $hash, $attrs ], $self;
-
-    tie $hash->%*, 'Pcore::Util::Hash::Multivalue::_HASH', $obj;
-
-    P->scalar->weaken( tied( $hash->%* )->[1] );
+    tie $hash->%*, $self;
 
     $obj->add(@_) if @_;
 
     return $obj;
 }
 
-sub attrs ($self) {
-    return $self->$*->[1];
+sub STORE {
+    $_[0]->{ $_[1] } = ref $_[2] eq 'ARRAY' ? $_[2] : [ $_[2] ];
+
+    return;
+}
+
+sub FETCH {
+    return $_[0]->{ $_[1] }->[-1] if exists $_[0]->{ $_[1] };
+
+    return;
 }
 
 sub clone ($self) {
@@ -38,20 +38,22 @@ sub clone ($self) {
 
 # return untied $hash->{$key} as ArrayRef
 sub get ( $self, $key ) {
-    if ( exists $self->$*->[0]->{$key} ) {
-        return tied( $self->$*->[0]->%* )->[0]->{$key};
+    if ( exists $self->{$key} ) {
+        return tied( $self->%* )->{$key};
+    }
+    else {
+        return;
     }
-
-    return;
 }
 
 # return untied HashRef
 sub get_hash ($self) {
-    return tied( $self->$*->[0]->%* )->[0];
+    return tied $self->%*;
 }
 
 sub add {
     my $self = shift;
+
     my $args = $self->_parse_args(@_);
 
     my $hash = $self->get_hash;
@@ -61,14 +63,14 @@ sub add {
             $hash->{ $args->[$i] } = ref $args->[ $i + 1 ] eq 'ARRAY' ? $args->[ $i + 1 ] : [ $args->[ $i + 1 ] ];
         }
         else {
-            push $hash->{ $args->[$i] }, ref $args->[ $i + 1 ] eq 'ARRAY' ? $args->[ $i + 1 ]->@* : $args->[ $i + 1 ];
+            push $hash->{ $args->[$i] }->@*, ref $args->[ $i + 1 ] eq 'ARRAY' ? $args->[ $i + 1 ]->@* : $args->[ $i + 1 ];
         }
     }
 
     return $self;
 }
 
-sub set {    ## no critic qw(NamingConventions::ProhibitAmbiguousNames)
+sub set {    ## no critic qw[NamingConventions::ProhibitAmbiguousNames]
     my $self = shift;
 
     return $self->clear->add(@_);
@@ -76,6 +78,7 @@ sub set {    ## no critic qw(NamingConventions::ProhibitAmbiguousNames)
 
 sub replace {
     my $self = shift;
+
     my $args = $self->_parse_args(@_);
 
     return $self->remove( pairkeys $args->@* )->add($args);
@@ -110,9 +113,9 @@ sub to_array ($self) {
 
     my $hash = $self->get_hash;
 
-    for my $key ( sort keys $hash ) {
+    for my $key ( sort keys $hash->%* ) {
         for my $val ( $hash->{$key}->@* ) {
-            push $array, $key => $val;
+            push $array->@*, $key => $val;
         }
     }
 
@@ -120,25 +123,7 @@ sub to_array ($self) {
 }
 
 sub TO_DUMP ( $self, $dumper, %args ) {
-    return dump $self->get_hash;
-}
-
-package Pcore::Util::Hash::Multivalue::_HASH;
-
-use Pcore;
-use Tie::Hash;
-use base qw[Tie::ExtraHash];
-
-sub STORE {
-    $_[0]->[0]->{ $_[1] } = ref $_[2] eq 'ARRAY' ? $_[2] : [ $_[2] ];
-
-    return;
-}
-
-sub FETCH {
-    return $_[0]->[0]->{ $_[1] }->[-1] if exists $_[0]->[0]->{ $_[1] };
-
-    return;
+    return dump { $self->get_hash->%* };
 }
 
 1;
@@ -148,12 +133,12 @@ sub FETCH {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 22, 24, 42, 50, 93,  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## │      │ 101                  │                                                                                                                │
+## │    3 │ 16, 42, 51, 96, 104, │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │      │ 116, 126             │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 22                   │ Miscellanea::ProhibitTies - Tied variable used                                                                 │
+## │    2 │ 16                   │ Miscellanea::ProhibitTies - Tied variable used                                                                 │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 59                   │ ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            │
+## │    2 │ 61                   │ ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
