@@ -2,11 +2,10 @@
 
 package main v0.1.0;
 
-use Pcore;
-use Const::Fast qw[];
+use Pcore qw[-const];
 use Benchmark qw[];
 
-Const::Fast::const our $COUNT => -3;
+const our $COUNT => -3;
 
 # benchmark regex operations with upgraded / downgraded UTF-8 scalar
 
